grobnercrystals documentation — grobnercrystals 1.0 documentation

# grobnercrystals documentation

grobnercrystals is a SageMath package for working with Gröbner crystal structures (introduced in this preprint).

Check out the Usage section for further information.

Note

This project is under active development.

## Contents

- Usage
  - Installation
  - Dependencies
- Examples
  - Example 1.5 (Double Bruhat Ideals)
  - Example 2.1 (Crystal operators)
  - Example 2.9 (Another non-bicrystalline ideal)
  - Example 3.8 (Test set algorithm)
  - Example 5.9 (Nilpotent matrix Hessenberg variety)
  - Example 6.20 (matrix matroid ideal, continued)
- Documentation
  - Permutations
  - Filtered RSK
  - Crystal Operators on Matrices
  - Polynomial Rings
  - Ideals and Bicrystalline Tests
  - Interesting Classes of Ideals
  - Group Action Checks
  - Polynomials and Schur Expansions